@@ -2,7 +2,6 @@ import yaml
 from autoclass import autoclass
 import pathlib
 from typing import Optional, Dict
-import os
 
 
 @autoclass
@@ -134,7 +133,8 @@ class Config:
     def add_processors(processors: str, project_dir: pathlib.Path):
         processors_dict = {}
 
-        # Splits the input string to get a list of processors names and their arguments
+        # Splits the input string to get a list of processors names and their
+        # arguments
         for processor in processors.split(";"):
             if processor:
                 # Splits the processor name and the arguments
@@ -142,8 +142,8 @@ class Config:
                 processor_name = p[0].strip()
                 processors_dict[processor_name] = []
                 processor_args = p[1:]
-                # Eliminates the whitespaces at the left of the arguments and appends to
-                # the list of arguments of the processor
+                # Eliminates the whitespaces at the left of the arguments and
+                # appends to the list of arguments of the processor
                 for arg in processor_args:
                     arg = arg.strip()
                     processors_dict[processor_name].append(arg)
@@ -345,13 +345,16 @@ class Config:
             print("BPE configuration:")
             if data["bpe"]["joint"]:
                 print(
-                    f" -  Joint training, with {data['bpe']['num_iterations']} number "
-                    f"of iterations and threshold {data['bpe']['threshold']}"
+                    f" -  Joint training, with {data['bpe']['num_iterations']}"
+                    f" number of iterations and threshold"
+                    f" {data['bpe']['threshold']}"
                 )
             else:
                 print(
-                    f" -  Disjoint training, with {data['bpe']['num_iterations']} "
-                    f"number of iterations and threshold {data['bpe']['threshold']}"
+                    f" -  Disjoint training, with"
+                    f" {data['bpe']['num_iterations']} "
+                    f"number of iterations and threshold"
+                    f" {data['bpe']['threshold']}"
                 )
         else:
             print("BPE not configured")
