@@ -3,6 +3,7 @@ import os
 import shutil
 from datetime import datetime
 from autoclass import autoclass
+import logging
 
 
 @autoclass
@@ -12,7 +13,11 @@ class BaseStage:
     REPORT = "report"
 
     def __init__(self, workflow, name):
-        pass
+        logging.basicConfig(
+            level=logging.INFO,
+            handlers=[logging.StreamHandler()],
+            format='%(asctime)s :: %(levelname)s :: %(message)s'
+        )
 
     async def run_with_time_report(self, *args, **kwargs):
         start = time.ctime(int(time.time()))
