@@ -12,6 +12,7 @@ from pangeamt_nlp.translation_model.translation_model_factory import (
 )
 from pangeamt_nlp.seg import Seg
 from nteu_translation_engine.engine import Engine
+import logging
 
 
 class EvalStage(BaseStage):
@@ -58,11 +59,11 @@ class EvalStage(BaseStage):
         if gpu is not None and gpu > -1:
             args["gpu"] = gpu
 
-        print("Loading model..")
+        logging.info("Loading model..")
 
         decoding_model = translation_model(model_path, **args)
 
-        print("Model loaded")
+        logging.info("Model loaded")
 
         with open(src_path, "r") as src_file, open(out_path, "w") as out_file:
             batch = []
@@ -96,7 +97,7 @@ class EvalStage(BaseStage):
         with open(out_path, "r") as sys_file, open(tgt_path, "r") as ref_file:
             final_score = corpus_bleu(sys_file, [ref_file]).score
 
-        print("Bleu score: ", final_score)
+        logging.info("Bleu score: ", final_score)
 
         return {
             "Score": final_score
@@ -133,7 +134,7 @@ class EvalStage(BaseStage):
         log_file: str,
         debug: bool
     ):
-        print("Loading model")
+        logging.info("Loading model")
         config = self.workflow.project.config.config_dict
         project = self.workflow.project
         project_dir = project.config.project_dir
@@ -200,4 +201,4 @@ class EvalStage(BaseStage):
         with open(out_path, "r") as sys_file, open(ref_path, "r") as ref_file:
             final_score = corpus_bleu(sys_file, [ref_file]).score
 
-        print("Score: ", final_score)
+        logging.info("Score: ", final_score)
