@@ -1,4 +1,5 @@
 import tempfile
+import logging
 import time
 import shutil
 import subprocess
@@ -172,7 +173,7 @@ class PrepareStage(BaseStage):
         all_lines.close()
 
         # Shuffle the data
-        print("Shufling and splitting data...")
+        logging.info("Shufling and splitting data...")
         command1 = (
             f'cat {all_lines_path} | sed -e "s/\r//g" | sed "s/\t//g" '
             f"| sort | uniq > {temp_path}"
@@ -242,7 +243,7 @@ class PrepareStage(BaseStage):
         subprocess.run(
             f"rm {all_lines_path} && rm {all_lines_shuf}", shell=True
         )
-        print("Finished shufling and splitting data")
+        logging.info("Finished shufling and splitting data")
 
     # Tokenize corpus
     async def tokenize(self, max_workers):
@@ -315,14 +316,14 @@ class PrepareStage(BaseStage):
 
         prev_dir = os.path.join(self.stage_dir, "02_tokenized")
 
-        print("Training truecase models if enabled...")
+        logging.info("Training truecase models if enabled...")
 
         (src_model_path, tgt_model_path) = self.create_truecase_model(
             prev_dir,
             max_workers
         )
 
-        print("Finished training")
+        logging.info("Finished training")
 
         # Initialize the truecaser for the different languages if the truecaser
         # is enabled, if not, let it None
@@ -431,11 +432,11 @@ class PrepareStage(BaseStage):
         joint = self.workflow.project.config.bpe["joint"]
         threshold = self.workflow.project.config.bpe["threshold"]
 
-        print("Training bpe models if enabled...")
+        logging.info("Training bpe models if enabled...")
 
         model_dir = self.create_bpe_model(prev_dir, joint)
 
-        print("Finished training bpe model")
+        logging.info("Finished training bpe model")
 
         # If joint, train the bpe with all the corpus, else, train with the
         # corpus split by language
@@ -479,7 +480,7 @@ class PrepareStage(BaseStage):
                 tgt_bpe,
             ),
         )
-
+        logging.info("Starting to apply bpe")
         for pair in files:
             bpe = pair[1]
             if bpe:
@@ -502,6 +503,7 @@ class PrepareStage(BaseStage):
                                 ) as bar:
                                     for bpe_line in bar:
                                         out_file.write(bpe_line)
+        logging.info("Finished applying bpe")
 
     # Create BPE model
     def create_bpe_model(self, prev_dir, joint):
